import defaultCountryCenter from "./defaultCountryCenter";

// Create leaflet map
function createMap(container, _ref) {
  var _window$L, _window;
  var center = _ref.center,
    _ref$minZoom = _ref.minZoom,
    minZoom = _ref$minZoom === void 0 ? 1 : _ref$minZoom,
    _ref$maxZoom = _ref.maxZoom,
    maxZoom = _ref$maxZoom === void 0 ? 20 : _ref$maxZoom,
    _ref$zoom = _ref.zoom,
    zoom = _ref$zoom === void 0 ? 13 : _ref$zoom;
  if (!window.L) {
    return '请在Map组件需要使用APILoader包裹';
  }
  if (!((_window$L = window.L) !== null && _window$L !== void 0 && (_window$L = _window$L.tileLayer) !== null && _window$L !== void 0 && _window$L.currentTileLayer)) {
    return '缺少必要地图资源, 请检查APILoader参数是否正确, 或者key是否过期';
  }

  // 百度地图最小3
  if (window.BMap && minZoom < 3) {
    // eslint-disable-next-line
    minZoom = 3;
  }
  var map = null;
  var centerPoint = [];
  if (center !== null && center !== void 0 && center.latitude && center !== null && center !== void 0 && center.longitude) {
    centerPoint = [center === null || center === void 0 ? void 0 : center.latitude, center === null || center === void 0 ? void 0 : center.longitude];
  }
  // 中国默认天安门
  else if (window.BMap) {
    centerPoint = [defaultCountryCenter['zh_CN'].latitude, defaultCountryCenter['zh_CN'].longitude];
  }
  // 国外默认白宫
  else {
    centerPoint = [defaultCountryCenter['other'].latitude, defaultCountryCenter['other'].longitude];
  }
  // Init leaflet map
  var config = {
    attributionControl: false,
    // 隐藏版权控件
    zoomControl: false,
    // 隐藏放大缩小控件
    maxZoom: maxZoom,
    minZoom: minZoom,
    zoom: zoom,
    center: centerPoint
  };
  // 百度tile layer插件
  if ((_window = window) !== null && _window !== void 0 && (_window = _window.L) !== null && _window !== void 0 && (_window = _window.CRS) !== null && _window !== void 0 && _window.Baidu) {
    config.crs = window.L.CRS.Baidu;
  }
  map = window.L.map(container, config);

  // Add tileLayer
  var tileLayer = window.L.tileLayer.currentTileLayer();
  tileLayer.addTo(map);
  return new Promise(function (resolve) {
    tileLayer.on('load', function () {
      resolve(map);
    });
  });
}
export default createMap;